rm(list = ls())
setwd(dirname(rstudioapi::getActiveDocumentContext()$path))

# packages used
listofpackages <- c("ggplot2", "dplyr", "magrittr", "readr", "tidyverse", "readxl", "urca", "tseries", "rvest","xlsx", 
                    "xts", "zoo", "dynlm", "magrittr", "quantmod","PerformanceAnalytics", "fPortfolio", "timeSeries", "dygraphs", "writexl")

for (j in listofpackages){
  if(sum(installed.packages()[, 1] == j) == 0) {
    install.packages(j)
  }
  library(j, character.only = T)
}

# 30 components of Dow Jones in January 2023

tickers <- c('AXP','AMGN','AAPL','BA','CAT','CSCO','CVX','GS','HD','HON',
             'IBM','INTC','JNJ','KO','JPM','MCD','MMM','MRK','MSFT','NKE',
             'PG','TRV','UNH','CRM','VZ','V','WBA','WMT','DIS','DOW','^DJI') #,'^GSPC',,'^IRX')

#download the historical prices
getSymbols.yahoo(tickers,
                 env = globalenv(),
                 index.class ='Date',
                 from = "1985-01-01",
                 to = "2022-12-01",
                 periodicity ="monthly")

stocks = merge(AXP[,6],AMGN[,6],AAPL[,6],BA[,6],CAT[,6],CSCO[,6],CVX[,6],GS[,6],HD[,6],HON[,6],
               IBM[,6],INTC[,6],JNJ[,6],KO[,6],JPM[,6],MCD[,6],MMM[,6],MRK[,6],MSFT[,6],NKE[,6],
               PG[,6],TRV[,6],UNH[,6],CRM[,6],VZ[,6],V[,6],WBA[,6],WMT[,6],DIS[,6],DOW[,6],DJI[,6])

colnames(stocks) <- c('AXP','AMGN','AAPL','BA','CAT','CSCO','CVX','GS','HD','HON',
                      'IBM','INTC','JNJ','KO','JPM','MCD','MMM','MRK','MSFT','NKE',
                      'PG','TRV','UNH','CRM','VZ','V','WBA','WMT','DIS','DOW','DJI')

write.xlsx(as.data.frame(stocks), "2022_monthly_stocks.xlsx", row.names = TRUE)
rm(list = c('AXP','AMGN','AAPL','BA','CAT','CSCO','CVX','GS','HD','HON',
            'IBM','INTC','JNJ','KO','JPM','MCD','MMM','MRK','MSFT','NKE',
            'PG','TRV','UNH','CRM','VZ','V','WBA','WMT','DIS','DOW','DJI'))
# Quarterly
stocks_quarterly = to.quarterly(stocks$AXP)[,4]

for(i in 2:ncol(stocks)){
  x = to.quarterly(stocks[, i])[,4]
  stocks_quarterly = merge(stocks_quarterly, x)
}

colnames(stocks_quarterly) <- c('AXP','AMGN','AAPL','BA','CAT','CSCO','CVX','GS','HD','HON',
                                'IBM','INTC','JNJ','KO','JPM','MCD','MMM','MRK','MSFT','NKE',
                                'PG','TRV','UNH','CRM','VZ','V','WBA','WMT','DIS','DOW','DJI')

write.xlsx(as.data.frame(stocks_quarterly), "2022_quarterly_stocks.xlsx", row.names = TRUE)





